@@ -89,13 +89,15 @@ class DMol3(FileIOCalculator):
     implemented_properties = ['energy', 'forces']
     default_parameters = {'functional': 'pbe',
                           'symmetry': 'on'}
+    discard_results_on_any_change = True
 
     if 'DMOL_COMMAND' in os.environ:
         command = os.environ['DMOL_COMMAND'] + ' PREFIX > PREFIX.out'
     else:
         command = None
 
-    def __init__(self, restart=None, ignore_bad_restart_file=False,
+    def __init__(self, restart=None,
+                 ignore_bad_restart_file=FileIOCalculator._deprecated,
                  label='dmol_calc/tmp', atoms=None, **kwargs):
         """ Construct DMol3 calculator. """
         FileIOCalculator.__init__(self, restart, ignore_bad_restart_file,
@@ -104,11 +106,6 @@ class DMol3(FileIOCalculator):
         # tracks if DMol transformed coordinate system
         self.internal_transformation = False
 
-    def set(self, **kwargs):
-        changed_parameters = FileIOCalculator.set(self, **kwargs)
-        if changed_parameters:
-            self.reset()
-
     def write_input(self, atoms, properties=None, system_changes=None):
 
         if not (np.all(atoms.pbc) or not np.any(atoms.pbc)):
@@ -131,8 +128,10 @@ class DMol3(FileIOCalculator):
 
     def write_input_file(self):
         """ Writes the input file. """
+        with open(self.label + '.input', 'w') as fd:
+            self._write_input_file(fd)
 
-        f = open(self.label + '.input', 'w')
+    def _write_input_file(self, f):
         f.write('%-32s %s\n' % ('calculate', 'gradient'))
 
         # if no key about eigs
@@ -182,7 +181,7 @@ class DMol3(FileIOCalculator):
         """
         finished = False
         message = ""
-        for line in open(self.label + '.outmol', 'r'):
+        for line in self._outmol_lines():
             if line.rfind('Message: DMol3 job finished successfully') > -1:
                 finished = True
             if line.startswith('Error'):
@@ -258,7 +257,7 @@ class DMol3(FileIOCalculator):
         atoms (Atoms object): read atoms object
         """
 
-        lines = open(self.label + '.outmol', 'r').readlines()
+        lines = self._outmol_lines()
         found_cell = False
         cell = np.zeros((3, 3))
         symbols = []
@@ -291,7 +290,7 @@ class DMol3(FileIOCalculator):
         """ Find and return last occurrence of Ef in outmole file. """
         energy_regex = re.compile(r'^Ef\s+(\S+)Ha')
         found = False
-        for line in open(self.label + '.outmol', 'r'):
+        for line in self._outmol_lines():
             match = energy_regex.match(line)
             if match:
                 energy = float(match.group(1))
@@ -303,7 +302,9 @@ class DMol3(FileIOCalculator):
     def read_forces(self):
         """ Read forces from .grad file. Applies self.rotation_matrix if
         self.internal_transformation is True. """
-        lines = open(self.label + '.grad', 'r').readlines()
+        with open(self.label + '.grad', 'r') as fd:
+            lines = fd.readlines()
+
         forces = []
         for i, line in enumerate(lines):
             if line.startswith('$gradients'):
@@ -362,7 +363,7 @@ class DMol3(FileIOCalculator):
         """
 
         assert mode in ['eigenvalues', 'occupations']
-        lines = open(self.label + '.outmol', 'r').readlines()
+        lines = self._outmol_lines()
         pattern_kpts = re.compile(r'Eigenvalues for kvector\s+%d' % (kpt + 1))
         for n, line in enumerate(lines):
 
@@ -404,11 +405,15 @@ class DMol3(FileIOCalculator):
                 return np.array(values)
         return None
 
+    def _outmol_lines(self):
+        with open(self.label + '.outmol', 'r') as fd:
+            return fd.readlines()
+
     def read_kpts(self, mode='ibz_k_points'):
         """ Returns list of kpts coordinates or kpts weights.  """
 
         assert mode in ['ibz_k_points', 'k_point_weights']
-        lines = open(self.label + '.outmol', 'r').readlines()
+        lines = self._outmol_ines()
 
         values = []
         for n, line in enumerate(lines):
@@ -425,7 +430,7 @@ class DMol3(FileIOCalculator):
     def read_spin_polarized(self):
         """Reads, from outmol file, if calculation is spin polarized."""
 
-        lines = open(self.label + '.outmol', 'r').readlines()
+        lines = self._outmol_lines()
         for n, line in enumerate(lines):
             if line.rfind('Calculation is Spin_restricted') > -1:
                 return False
@@ -439,7 +444,7 @@ class DMol3(FileIOCalculator):
         Example line in outmol:
         Fermi Energy:           -0.225556 Ha     -6.138 eV   xyz text
         """
-        lines = open(self.label + '.outmol', 'r').readlines()
+        lines = self._outmol_lines()
         pattern_fermi = re.compile(r'Fermi Energy:\s+(\S+)\s+Ha')
         for line in lines:
             m = pattern_fermi.match(line)
@@ -450,7 +455,7 @@ class DMol3(FileIOCalculator):
     def read_energy_contributions(self):
         """Reads the different energy contributions."""
 
-        lines = open(self.label + '.outmol', 'r').readlines()
+        lines = self._outmol_lines()
         energies = dict()
         for n, line in enumerate(lines):
             if line.startswith('Energy components'):
@@ -582,7 +587,8 @@ def read_grd(filename):
     """
     from ase.geometry.cell import cellpar_to_cell
 
-    lines = open(filename, 'r').readlines()
+    with open(filename, 'r') as fd:
+        lines = fd.readlines()
 
     cell_data = np.array([float(fld) for fld in lines[2].split()])
     cell = cellpar_to_cell(cell_data)
