@@ -37,6 +37,12 @@ from ase.calculators.openmx.writer import write_openmx
 #from ase.calculators.openmx.dos import DOS
 
 
+def parse_omx_version(txt):
+    """Parse version number from stdout header."""
+    match = re.search(r'Welcome to OpenMX\s+Ver\.\s+(\S+)', txt, re.M)
+    return match.group(1)
+
+
 class OpenMX(FileIOCalculator):
     """
     Calculator interface to the OpenMX code.
@@ -45,6 +51,7 @@ class OpenMX(FileIOCalculator):
     implemented_properties = [
         'free_energy',       # Same value with energy
         'energy',
+        'energies',
         'forces',
         'stress',
         'dipole',
@@ -72,7 +79,8 @@ class OpenMX(FileIOCalculator):
         'debug': False
     }
 
-    def __init__(self, restart=None, ignore_bad_restart_file=False,
+    def __init__(self, restart=None,
+                 ignore_bad_restart_file=FileIOCalculator._deprecated,
                  label='./openmx', atoms=None, command=None, mpi=None,
                  pbs=None, **kwargs):
 
@@ -300,9 +308,9 @@ class OpenMX(FileIOCalculator):
         See base FileIOCalculator for documentation.
         """
         if self.parameters.data_path is None:
-            if not 'OPENMX_DFT_DATA_PATH' in os.environ:
+            if 'OPENMX_DFT_DATA_PATH' not in os.environ:
                 warnings.warn('Please either set OPENMX_DFT_DATA_PATH as an'
-                              'enviroment variable or specify dft_data_path as'
+                              'enviroment variable or specify "data_path" as'
                               'a keyword argument')
 
         self.prind("Start Calculation")
@@ -473,7 +481,7 @@ class OpenMX(FileIOCalculator):
                 threads_string = ''
             command += 'mpirun -np ' + \
                 str(processes) + ' ' + self.command + ' %s ' + threads_string + ' |tee %s'
-                #str(processes) + ' openmx %s' + threads_string + ' > %s'
+            #str(processes) + ' openmx %s' + threads_string + ' > %s'
 
         if runfile is None:
             runfile = abs_dir + '/' + self.prefix + '.dat'
