@@ -156,7 +156,7 @@ class SiestaParameters(Parameters):
             symlink_pseudos=None,
             atoms=None,
             restart=None,
-            ignore_bad_restart_file=False,
+            ignore_bad_restart_file=FileIOCalculator._deprecated,
             fdf_arguments=None,
             atomic_coord_format='xyz',
             bandpath=None):
@@ -656,14 +656,19 @@ class Siesta(FileIOCalculator):
         # no spin. SIESTA default is FM initialization, if the
         # block is not written, but  we must conform to the
         # atoms object.
-        if self['spin'] != 'non-polarized':
-            if sum(abs(magmoms)) == 0:
+        if magmoms is not None:
+            if len(magmoms) == 0:
                 f.write('#Empty block forces ASE initialization.\n')
 
             f.write('%block DM.InitSpin\n')
-            for n, M in enumerate(magmoms):
-                if M != 0:
-                    f.write('    %d %.14f\n' % (n + 1, M))
+            if len(magmoms) != 0 and isinstance(magmoms[0], np.ndarray):
+                for n, M in enumerate(magmoms):
+                    if M[0] != 0:
+                        f.write('    %d %.14f %.14f %.14f \n' % (n + 1, M[0], M[1], M[2]))
+            elif len(magmoms) != 0 and isinstance(magmoms[0], float):
+                for n, M in enumerate(magmoms):
+                    if M != 0:
+                        f.write('    %d %.14f \n' % (n + 1, M))
             f.write('%endblock DM.InitSpin\n')
             f.write('\n')
 
@@ -971,7 +976,8 @@ class Siesta(FileIOCalculator):
         return self.results['bandstructure']
 
     def read_ion(self, atoms):
-        """Read the ion.xml file of each specie
+        """
+        Read the ion.xml file of each specie
         """
         from ase.calculators.siesta.import_ion_xml import get_ion
 
@@ -1154,7 +1160,7 @@ class Siesta(FileIOCalculator):
                 self.results['fermi_energy'] = float(f.readline())
                 n, nspin, nkp = map(int, f.readline().split())
                 _ee = np.split(
-                    np.array(f.read().split()).astype(np.float), nkp)
+                    np.array(f.read().split()).astype(float), nkp)
         except (IOError):
             return 1
 
@@ -1207,512 +1213,6 @@ class Siesta(FileIOCalculator):
         # debye to e*Ang
         self.results['dipole'] = dipole * 0.2081943482534
 
-    def pyscf_tddft(
-            self,
-            Edir=np.array([1.0, 0.0, 0.0]),
-            freq=np.arange(0.0, 10.0, 0.1),
-            units='au',
-            run_tddft=True,
-            save_kernel=True,
-            kernel_name="tddft_kernel.npy",
-            fname="pol_tensor.npy",
-            fname_nonin="noninpol_tensor.npy", **kw):
-        """
-        Perform TDDFT calculation using the pyscf.nao module for a molecule.
-
-        Parameters
-        ----------
-        freq: array like
-            frequency range for which the polarizability should
-            be computed, in eV
-        units : str, optional
-            unit for the returned polarizability, can be au (atomic units)
-            or nm**2
-        run_tddft: to run the tddft_calculation or not
-        fname: str
-            Name of input file name for polariazbility tensor.
-            if run_tddft is True: output file
-            if run_tddft is False: input file
-
-        kw: keywords for the tddft_iter function from pyscf
-
-        Returns
-        -------
-            Add to the self.results dict the following items:
-        freq range: array like
-            array of dimension (nff) containing the frequency range in eV.
-
-        polarizability nonin: array like (complex)
-            array of dimension (nff, 3, 3) with nff the frequency number,
-            the second and third dimension are the matrix elements of the
-            non-interactive polarizability::
-
-                P_xx, P_xy, P_xz, Pyx, .......
-
-
-        polarizability: array like (complex)
-            array of dimension (nff, 3, 3) with nff the frequency number,
-            the second and third dimension are the matrix elements of the
-            interactive polarizability::
-
-                P_xx, P_xy, P_xz, Pyx, .......
-
-        density change nonin: array like (complex)
-            contains the non interacting density change in product basis
-
-        density change inter: array like (complex)
-            contains the interacting density change in product basis
-
-        References
-        ----------
-        https://github.com/cfm-mpc/pyscf/tree/nao
-
-        Example
-        -------
-        from ase.units import Ry, eV, Ha
-        from ase.calculators.siesta import Siesta
-        from ase import Atoms
-        import numpy as np
-        import matplotlib.pyplot as plt
-
-        # Define the systems
-        Na8 = Atoms('Na8',
-                     positions=[[-1.90503810, 1.56107288, 0.00000000],
-                                [1.90503810, 1.56107288, 0.00000000],
-                                [1.90503810, -1.56107288, 0.00000000],
-                                [-1.90503810, -1.56107288, 0.00000000],
-                                [0.00000000, 0.00000000, 2.08495836],
-                                [0.00000000, 0.00000000, -2.08495836],
-                                [0.00000000, 3.22798122, 2.08495836],
-                                [0.00000000, 3.22798122, -2.08495836]],
-                     cell=[20, 20, 20])
-
-        # Siesta input
-        siesta = Siesta(
-                    mesh_cutoff=150 * Ry,
-                    basis_set='DZP',
-                    pseudo_qualifier='',
-                    energy_shift=(10 * 10**-3) * eV,
-                    fdf_arguments={
-                        'SCFMustConverge': False,
-                        'COOP.Write': True,
-                        'WriteDenchar': True,
-                        'PAO.BasisType': 'split',
-                        'DM.Tolerance': 1e-4,
-                        'DM.MixingWeight': 0.01,
-                        'MaxSCFIterations': 300,
-                        'DM.NumberPulay': 4,
-                        'XML.Write': True})
-
-        Na8.calc = siesta
-        e = Na8.get_potential_energy()
-        freq, pol = siesta.get_polarizability_pyscf_inter(
-            label="siesta",
-            jcutoff=7,
-            iter_broadening=0.15/Ha,
-            xc_code='LDA,PZ',
-            tol_loc=1e-6,
-            tol_biloc=1e-7,
-            freq = np.arange(0.0, 5.0, 0.05))
-        # plot polarizability
-        plt.plot(freq, pol[:, 0, 0].imag)
-        plt.show()
-        """
-
-        from ase.calculators.siesta.mbpt_lcao_utils import pol2cross_sec
-        assert units in ["nm**2", "au"]
-
-        if run_tddft:
-            from pyscf.nao import tddft_iter
-            from ase.units import Ha
-
-            tddft = tddft_iter(**kw)
-            if save_kernel:
-                np.save(kernel_name, tddft.kernel)
-
-            omegas = freq / Ha + 1j * tddft.eps
-            tddft.comp_dens_nonin_along_Eext(omegas, Eext=Edir)
-            tddft.comp_dens_inter_along_Eext(omegas, Eext=Edir)
-
-            # save polarizability tensor and density change to files
-            self.results["freq range"] = freq
-            self.results['polarizability nonin'] = np.zeros(
-                (freq.size, 3, 3),
-                dtype=tddft.p0_mat.dtype)
-            self.results['polarizability inter'] = np.zeros(
-                (freq.size, 3, 3),
-                dtype=tddft.p_mat.dtype)
-            self.results["density change nonin"] = tddft.dn0
-            self.results["density change inter"] = tddft.dn
-            for xyz1 in range(3):
-                for xyz2 in range(3):
-                    if units == 'nm**2':
-                        p0 = pol2cross_sec(-tddft.p0_mat[xyz1, xyz2, :], freq)
-                        p = pol2cross_sec(-tddft.p_mat[xyz1, xyz2, :], freq)
-                        self.results['polarizability nonin'][:, xyz1, xyz2] = \
-                            p0
-                        self.results['polarizability inter'][:, xyz1, xyz2] = \
-                            p
-                    else:
-                        self.results['polarizability nonin'][:, xyz1, xyz2] = \
-                            -tddft.p0_mat[xyz1, xyz2, :]
-                        self.results['polarizability inter'][:, xyz1, xyz2] = \
-                            -tddft.p_mat[xyz1, xyz2, :]
-
-        else:
-            # load polarizability tensor from previous calculations
-            p0_mat = np.load(fname_nonin)
-            p_mat = np.load(fname)
-
-            self.results['polarizability nonin'] = np.zeros(
-                (freq.size, 3, 3),
-                dtype=p0_mat.dtype)
-            self.results['polarizability inter'] = np.zeros(
-                (freq.size, 3, 3),
-                dtype=p_mat.dtype)
-
-            for xyz1 in range(3):
-                for xyz2 in range(3):
-                    if units == 'nm**2':
-                        p0 = pol2cross_sec(-p0_mat[xyz1, xyz2, :], freq)
-                        p = pol2cross_sec(-p_mat[xyz1, xyz2, :], freq)
-
-                        self.results['polarizability nonin'][:, xyz1, xyz2] = \
-                            p0
-                        self.results['polarizability inter'][:, xyz1, xyz2] = \
-                            p
-                    else:
-                        self.results['polarizability nonin'][:, xyz1, xyz2] = \
-                            -p0_mat[xyz1, xyz2, :]
-                        self.results['polarizability inter'][:, xyz1, xyz2] = \
-                            -p_mat[xyz1, xyz2, :]
-
-    def pyscf_tddft_eels(
-            self,
-            velec=np.array([20.0, 0.0, 0.0]),
-            b=np.array([0.0, 0.0, 0.0]),
-            freq=np.arange(0.0, 10.0, 0.1),
-            tddft=None,
-            save_kernel=True,
-            kernel_name="tddft_kernel.npy",
-            tmp_fname=None,
-            **kw):
-        r"""
-        Perform TDDFT calculation using the pyscf.nao module for a molecule.
-        The external perturbation is created by a electron moving at
-        the velocity velec and with an impact parameter b.
-
-        Parameters
-        ----------
-        freq: array like
-            frequency range for which the polarizability should
-            be computed, in eV
-        velec: array like
-            velocity vector of the projectile
-        b: array like
-            offset vector of the projectile
-        tddft: tddft_tem class from a previous calculation
-        save_kernel: save the kernel for future use
-        kernel_name: name of the file for the kernel
-        tmp_fname: temporary name to save the eels spectra
-        while running the calculations.
-        kw: keywords for the tddft_tem function from pyscf
-
-        Returns
-        -------
-        tddft:
-            if running pyscf_tddft_eels in a loop over the velocity or the
-            impact parameter, there is no point to initialize again the tddft
-            calculation (vertex and kernel will be the same)
-
-            Add to the self.results dict the following items:
-        freq range: array like
-            array of dimension (nff) containing the frequency range in eV.
-
-        eel spectra nonin: array like (complex)
-            array of dimension (nff) with nff the frequency number,
-
-
-        eel spectra inter: array like (complex)
-            array of dimension (nff) with nff the frequency number,
-
-        density change eels nonin: array like (complex)
-            contains the non interacting density change in product basis
-
-        density change eels inter: array like (complex)
-            contains the interacting density change in product basis
-
-        References
-        ----------
-        https://github.com/cfm-mpc/pyscf/tree/nao
-
-        Example
-        -------
-        from ase.units import Ry, eV, Ha
-        from ase.calculators.siesta import Siesta
-        from ase import Atoms
-        import numpy as np
-        import matplotlib.pyplot as plt
-
-        # Define the systems
-        Na8 = Atoms('Na8',
-                    positions=[[-1.90503810, 1.56107288, 0.00000000],
-                               [1.90503810, 1.56107288, 0.00000000],
-                               [1.90503810, -1.56107288, 0.00000000],
-                               [-1.90503810, -1.56107288, 0.00000000],
-                               [0.00000000, 0.00000000, 2.08495836],
-                               [0.00000000, 0.00000000, -2.08495836],
-                               [0.00000000, 3.22798122, 2.08495836],
-                               [0.00000000, 3.22798122, -2.08495836]],
-                    cell=[20, 20, 20])
-
-        # enter siesta input
-        siesta = Siesta(
-            mesh_cutoff=150 * Ry,
-            basis_set='DZP',
-            pseudo_qualifier='',
-            energy_shift=(10 * 10**-3) * eV,
-            fdf_arguments={
-                'SCFMustConverge': False,
-                'COOP.Write': True,
-                'WriteDenchar': True,
-                'PAO.BasisType': 'split',
-                'DM.Tolerance': 1e-4,
-                'DM.MixingWeight': 0.01,
-                'MaxSCFIterations': 300,
-                'DM.NumberPulay': 4,
-                'XML.Write': True})
-
-
-        Na8.calc = siesta
-        e = Na8.get_potential_energy()
-        tddft = siesta.pyscf_tddft_eels(
-            label="siesta", jcutoff=7, iter_broadening=0.15/Ha,
-            xc_code='LDA,PZ', tol_loc=1e-6, tol_biloc=1e-7,
-            freq=np.arange(0.0, 5.0, 0.05))
-
-        # plot eel spectra
-        fig = plt.figure(1)
-        ax1 = fig.add_subplot(121)
-        ax2 = fig.add_subplot(122)
-        ax1.plot(siesta.results["freq range"],
-                 siesta.results["eel spectra nonin"].imag)
-        ax2.plot(siesta.results["freq range"],
-                 siesta.results["eel spectra inter"].imag)
-
-        ax1.set_xlabel(r"$\omega$ (eV)")
-        ax2.set_xlabel(r"$\omega$ (eV)")
-
-        ax1.set_ylabel(r"Im($P_{xx}$) (au)")
-        ax2.set_ylabel(r"Im($P_{xx}$) (au)")
-
-        ax1.set_title(r"Non interacting")
-        ax2.set_title(r"Interacting")
-
-        fig.tight_layout()
-        plt.show()
-        """
-        from pyscf.nao import tddft_tem
-        from ase.units import Ha
-
-        assert velec.size == 3
-        assert b.size == 3
-
-        if tddft is None:
-            self.results["freq range"] = freq
-            omegas = freq / Ha
-
-            # for eels, omega is real array
-            tddft = tddft_tem(freq=omegas, **kw)
-            if save_kernel:
-                np.save(kernel_name, tddft.kernel)
-
-        self.results['eel spectra nonin'] = \
-            tddft.get_spectrum_nonin(velec=velec,
-                                     beam_offset=b,
-                                     tmp_fname=tmp_fname)
-
-        self.results['eel spectra inter'] = \
-            tddft.get_spectrum_inter(velec=velec,
-                                     beam_offset=b,
-                                     tmp_fname=tmp_fname)
-
-        self.results["density change eels nonin"] = tddft.dn0
-        self.results["density change eels inter"] = tddft.dn
-
-        return tddft
-
-    def get_polarizability_mbpt(self, mbpt_inp=None,
-                                output_name='mbpt_lcao.out',
-                                format_output='hdf5', units='au'):
-        """
-        Warning!!
-            Out dated version, try get_polarizability_pyscf
-
-
-        Calculate the polarizability by running the mbpt_lcao program.
-        The mbpt_lcao program need the siesta output, therefore siesta need
-        to be run first.
-
-        Parameters
-        ----------
-        mbpt_inp : dict, optional
-            dictionary of the input for the mbpt_lcao program
-            (http://mbpt-domiprod.wikidot.com/list-of-parameters)
-            if mbpt_inp is None, the function read the output file
-            from a previous mbpt_lcao run.
-        output_name : str, optional
-            Name of the mbpt_lcao output
-        format_output : str, optional
-            Format of the mbpt_lcao output data,
-            if hdf5, the output name is tddft_iter_output.hdf5 if
-            do_tddft_iter is set to 1 the output name is
-            tddft_tem_output.hdf5 if do_tddft_tem is set to 1
-            if txt, a lot of output data files are produced depending on
-            the input, in the text and fortran binaries format
-        units : str, optional
-            unit for the returned polarizability, can be au (atomic units)
-            or nm**2
-
-        Returns
-        -------
-        freq : array like
-            array of dimension (nff) containing the frequency range in eV.
-
-        self.results['polarizability'], array like
-            array of dimension (nff, 3, 3) with nff the frequency number,
-            the second and third dimension are the matrix elements of the
-            polarizability::
-
-                P_xx, P_xy, P_xz, Pyx, .......
-
-        References
-        ----------
-        http://mbpt-domiprod.wikidot.com
-
-        Example
-        -------
-        import os
-        from ase.units import Ry, eV
-        from ase.calculators.siesta import Siesta
-        from ase import Atoms
-        import numpy as np
-        import matplotlib.pyplot as plt
-
-        #Define the systems
-        Na8 = Atoms('Na8',
-        positions=[[-1.90503810, 1.56107288, 0.00000000],
-                    [1.90503810, 1.56107288, 0.00000000],
-                    [1.90503810, -1.56107288, 0.00000000],
-                    [-1.90503810, -1.56107288, 0.00000000],
-                    [0.00000000, 0.00000000, 2.08495836],
-                    [0.00000000, 0.00000000, -2.08495836],
-                    [0.00000000, 3.22798122, 2.08495836],
-                    [0.00000000, 3.22798122, -2.08495836]],
-                    cell=[20, 20, 20])
-
-        #enter siesta input
-        siesta = Siesta(
-            mesh_cutoff=150 * Ry,
-            basis_set='DZP',
-            pseudo_qualifier='',
-            energy_shift=(10 * 10**-3) * eV,
-            fdf_arguments={
-            'SCFMustConverge': False,
-            'COOP.Write': True,
-            'WriteDenchar': True,
-            'PAO.BasisType': 'split',
-            'DM.Tolerance': 1e-4,
-            'DM.MixingWeight': 0.01,
-            'MaxSCFIterations': 300,
-            'DM.NumberPulay': 4})
-
-
-        #mbpt_lcao input
-        mbpt_inp = {'prod_basis_type' : 'MIXED',
-                    'solver_type' : 1,
-                    'gmres_eps' : 0.001,
-                    'gmres_itermax':256,
-                    'gmres_restart':250,
-                    'gmres_verbose':20,
-                    'xc_ord_lebedev':14,
-                    'xc_ord_gl':48,
-                    'nr':512,
-                    'akmx':100,
-                    'eigmin_local':1e-06,
-                    'eigmin_bilocal':1e-08,
-                    'freq_eps_win1':0.15,
-                    'd_omega_win1':0.05,
-                    'dt':0.1,
-                    'omega_max_win1':5.0,
-                    'ext_field_direction':2,
-                    'dr':np.array([0.3, 0.3, 0.3]),
-                    'para_type':'MATRIX',
-                    'chi0_v_algorithm':14,
-                    'format_output':'text',
-                    'comp_dens_chng_and_polarizability':1,
-                    'store_dens_chng':1,
-                    'enh_given_volume_and_freq':0,
-                    'diag_hs':0,
-                    'do_tddft_tem':0,
-                    'do_tddft_iter':1,
-                    'plot_freq':3.02,
-                    'gwa_initialization':'SIESTA_PB'}
-
-
-        Na8.calc = siesta
-        e = Na8.get_potential_energy() #run siesta
-        freq, pol = siesta.get_polarizability_siesta(mbpt_inp,
-                                                     format_output='txt',
-                                                     units='nm**2')
-
-        #plot polarizability
-        plt.plot(freq, pol[:, 0, 0])
-
-        plt.show()
-        """
-        from ase.calculators.siesta.mbpt_lcao import MBPT_LCAO
-        from ase.calculators.siesta.mbpt_lcao_io import read_mbpt_lcao_output
-
-        warnings.warn("Out dated version, try get_polarizability_pyscf")
-
-        if mbpt_inp is not None:
-            tddft = MBPT_LCAO(mbpt_inp)
-            tddft.run_mbpt_lcao(output_name, True)
-
-        r = read_mbpt_lcao_output()
-
-        r.args.format_input = format_output
-
-        # read real part
-        r.args.ReIm = 're'
-        data = r.Read()
-        self.results['polarizability'] = data.Array
-
-        # read imaginary part
-        r.args.ReIm = 'im'
-        data = r.Read()
-        self.results['polarizability'] = (self.results['polarizability'] +
-                                          complex(0.0, 1.0) * data.Array)
-
-        if units == 'nm**2':
-            from ase.calculators.siesta.mbpt_lcao_utils import pol2cross_sec
-            for i in range(2):
-                for j in range(2):
-                    p = pol2cross_sec(self.results['polarizability'][:, i, j],
-                                      data.freq)
-                    self.results['polarizability'][:, i, j] = p
-
-            print('unit nm**2')
-            # self.results['polarizability'] = data.Array
-        elif units == 'au':
-            print('unit au')
-            # self.results['polarizability'] = data.Array
-        else:
-            raise ValueError('units can be only au or nm**2')
-
-        return data.freq, self.results['polarizability']
-
     def get_fermi_level(self):
         return self.results['fermi_energy']
 
@@ -1722,7 +1222,6 @@ class Siesta(FileIOCalculator):
     def get_ibz_k_points(self):
         return self.results['kpoints']
 
-
 class Siesta3_2(Siesta):
     def __init__(self, *args, **kwargs):
         warnings.warn(
