@@ -588,7 +588,7 @@ class Turbomole(FileIOCalculator):
     def __init__(self, label=None, calculate_energy='dscf',
                  calculate_forces='grad', post_HF=False, atoms=None,
                  restart=False, define_str=None, control_kdg=None,
-                 control_input=None, **kwargs):
+                 control_input=None, reset_tolerance=1e-2, **kwargs):
 
         FileIOCalculator.__init__(self)
 
@@ -600,6 +600,7 @@ class Turbomole(FileIOCalculator):
         self.define_str = define_str
         self.control_kdg = control_kdg
         self.control_input = control_input
+        self.reset_tolerance = reset_tolerance
 
         # construct flat dictionaries with parameter attributes
         for p in self.parameter_spec:
@@ -806,7 +807,7 @@ class Turbomole(FileIOCalculator):
     def set_atoms(self, atoms):
         """Create the self.atoms object and writes the coord file. If
         self.atoms exists a check for changes and an update of the atoms
-        are performed. Note: Only positions changes are tracked in this
+        is performed. Note: Only positions changes are tracked in this
         version.
         """
         changes = self.check_state(atoms, tol=1e-13)
@@ -820,7 +821,7 @@ class Turbomole(FileIOCalculator):
             else:
                 return
 
-        changes = self.check_state(atoms, tol=1e-2)
+        changes = self.check_state(atoms, tol=self.reset_tolerance)
         if 'positions' in changes:
             # print(two atoms obj are different')
             self.reset()
@@ -874,7 +875,7 @@ class Turbomole(FileIOCalculator):
         else:
             single_atom_str = '\n'
 
-        if params['multiplicity'] == 1:
+        if params['multiplicity'] == 1 and not params['uhf']:
             norb_str = ''
         else:
             norb_str = 'n\n'
@@ -1705,8 +1706,12 @@ class Turbomole(FileIOCalculator):
                 x = float(match.group(1)) * Bohr
                 y = float(match.group(3)) * Bohr
                 z = float(match.group(5)) * Bohr
-                symbol = str(match.group(7))
-                atoms += Atom(symbol.capitalize(), (x, y, z))
+                symbol = str(match.group(7)).capitalize()
+
+                if symbol == 'Q':
+                    symbol = 'X'
+                atoms += Atom(symbol, (x, y, z))
+
                 continue
             # gradient lines
             regex = (
@@ -1974,8 +1979,7 @@ class Turbomole(FileIOCalculator):
         return self.forces.copy()
 
     def get_dipole_moment(self, atoms):
-        if self.update_energy:
-            self.get_potential_energy(atoms)
+        self.get_potential_energy(atoms)
         self.read_dipole_moment()
         return self.dipole
 
@@ -2027,9 +2031,8 @@ class Turbomole(FileIOCalculator):
 
     def get_charges(self, atoms):
         """return partial charges on atoms from an ESP fit"""
-        if self.charges is None:
-            self.calculate(atoms)
-            self.read_charges()
+        self.get_potential_energy(atoms)
+        self.read_charges()
         return self.charges
 
     def read_charges(self):
