@@ -149,7 +149,6 @@ class Row:
         self.dct = dct
         self.values = None
         self.strings = None
-        self.more = False
         self.set_columns(columns)
         self.uid = dct[unique_key]
 
@@ -164,9 +163,6 @@ class Row:
                 value = getattr(self.dct, c, None)
             self.values.append(value)
 
-    def toggle(self):
-        self.more = not self.more
-
     def format(self, columns, subscript=None):
         self.strings = []
         numbers = set()
