@@ -1,10 +1,8 @@
 """Helper functions for Flask WSGI-app."""
 import re
-from typing import List, Tuple, Dict, Any, Optional
+from typing import Any, Dict, List, Optional, Tuple
 
-from flask import flash
-
-from ase.db.core import default_key_descriptions, Database
+from ase.db.core import Database, default_key_descriptions
 from ase.db.table import Table, all_columns
 
 
@@ -49,6 +47,7 @@ class Session:
         if what == 'query':
             self.query = project['handle_query_function'](args)
             self.nrows = None
+            self.page = 0
 
         elif what == 'sort':
             if x == self.sort:
@@ -127,6 +126,7 @@ class Session:
                 self.nrows = db.count(query)
             except (ValueError, KeyError) as e:
                 error = ', '.join(['Bad query'] + list(e.args))
+                from flask import flash
                 flash(error)
                 query = 'id=0'  # this will return no rows
                 self.nrows = 0
