@@ -210,7 +210,11 @@ def bz_plot(cell, vectors=False, paths=None, points=None,
         xx = plt.figaspect(1.0)
         fig.set_figheight(xx[1])
         fig.set_figwidth(xx[0])
-        ax.set_proj_type('ortho')
+
+        # oldlibs tests with matplotlib 2.0.0 say we have no set_proj_type:
+        if hasattr(ax, 'set_proj_type'):
+            ax.set_proj_type('ortho')
+
         minp0 = 0.9 * minp  # Here we cheat a bit to trim spacings
         maxp0 = 0.9 * maxp
         ax.set_xlim3d(minp0, maxp0)
