@@ -29,9 +29,9 @@ class ModifyAtoms:
         win.add([_('Moment'), self.magmom])
 
         atoms = self.gui.atoms
-        Z = atoms.numbers
-        if Z.ptp() == 0:
-            element.Z = Z[0]
+        sym = atoms.symbols[selected]
+        if len(sym.species()) == 1:
+            element.symbol = sym[0]
 
         tags = atoms.get_tags()[selected]
         if tags.ptp() == 0:
