@@ -9,8 +9,8 @@ def main():
         from ase.eos import plot
         plot(*data)
     elif task == 'neb':
-        from ase.neb import plot_band_from_fit
-        plot_band_from_fit(*data)
+        forcefit = data
+        forcefit.plot()
     elif task == 'reciprocal':
         from ase.dft.bz import bz_plot
         bz_plot(**data)
@@ -27,5 +27,6 @@ def main():
 
     plt.show()
 
+
 if __name__ == '__main__':
     main()
