@@ -7,7 +7,6 @@ import numpy as np
 import ase.gui.ui as ui
 from ase.io.formats import (write, parse_filename, get_ioformat, string2index,
                             filetype)
-from ase.utils import basestring
 
 
 text = _("""\
@@ -31,7 +30,7 @@ def save_dialog(gui, filename=None):
     filename, index = parse_filename(filename)
     if index is None:
         index = slice(gui.frame, gui.frame + 1)
-    elif isinstance(index, basestring):
+    elif isinstance(index, str):
         index = string2index(index)
     elif isinstance(index, slice):
         pass
