@@ -2,6 +2,7 @@ import os
 from os.path import join
 import re
 from glob import glob
+import warnings
 
 import numpy as np
 
@@ -151,7 +152,7 @@ keys_with_units = {
     'latticeconstant': 'Ang'}
 
 
-def write_abinit_in(fd, atoms, param=None, species=None):
+def write_abinit_in(fd, atoms, param=None, species=None, pseudos=None):
     import copy
     from ase.calculators.calculator import kpts2mp
     from ase.calculators.abinit import Abinit
@@ -249,7 +250,7 @@ def write_abinit_in(fd, atoms, param=None, species=None):
     fd.write('acell\n')
     fd.write('%.14f %.14f %.14f Angstrom\n' % (1.0, 1.0, 1.0))
     fd.write('rprim\n')
-    if atoms.number_of_lattice_vectors != 3:
+    if atoms.cell.rank != 3:
         raise RuntimeError('Abinit requires a 3D cell, but cell is {}'
                            .format(atoms.cell))
     for v in atoms.cell:
@@ -263,6 +264,7 @@ def write_abinit_in(fd, atoms, param=None, species=None):
     fd.write('#Enumerate different atomic species\n')
     fd.write('typat')
     fd.write('\n')
+
     types = []
     for Z in atoms.numbers:
         for n, Zs in enumerate(species):
@@ -275,14 +277,20 @@ def write_abinit_in(fd, atoms, param=None, species=None):
             fd.write('\n')
     fd.write('\n')
 
+    if pseudos is not None:
+        listing = ', '.join(pseudos)
+        line = f'pseudos "{listing}"\n'
+        fd.write(line)
+
     fd.write('#Definition of the atoms\n')
-    fd.write('xangst\n')
-    for pos in atoms.positions:
+    fd.write('xcart\n')
+    for pos in atoms.positions / Bohr:
         fd.write('%.14f %.14f %.14f\n' % tuple(pos))
 
     fd.write('chkexit 1 # abinit.exit file in the running '
              'directory terminates after the current SCF\n')
 
+
 def write_list(fd, value, unit):
     for element in value:
         fd.write("{} ".format(element))
@@ -290,6 +298,7 @@ def write_list(fd, value, unit):
         fd.write("{}".format(unit))
     fd.write("\n")
 
+
 def read_stress(fd):
     # sigma(1 1)=  4.02063464E-04  sigma(3 2)=  0.00000000E+00
     # sigma(2 2)=  4.02063464E-04  sigma(3 1)=  0.00000000E+00
@@ -307,7 +316,7 @@ def read_stress(fd):
         stress[i] = float(m.group(1))
         stress[i + 3] = float(m.group(2))
     unit = Hartree / Bohr**3
-    return stress / unit
+    return stress * unit
 
 
 def consume_multiline(fd, headerline, nvalues, dtype):
@@ -341,7 +350,10 @@ def read_abinit_out(fd):
     line = skipto('Version')
     m = re.match(r'\.*?Version\s+(\S+)\s+of ABINIT', line)
     assert m is not None
-    results['version'] = m.group(1)
+    version = m.group(1)
+    results['version'] = version
+
+    use_v9_format = int(version.split('.', 1)[0]) >= 9
 
     shape_vars = {}
 
@@ -388,6 +400,19 @@ def read_abinit_out(fd):
         arr = np.array(arr).astype(float)
         return arr
 
+    if use_v9_format:
+        energy_header = '--- !EnergyTerms'
+        total_energy_name = 'total_energy_eV'
+
+        def parse_energy(line):
+            return float(line.split(':')[1].strip())
+    else:
+        energy_header = 'Components of total free energy (in Hartree) :'
+        total_energy_name = '>>>>>>>>> Etotal'
+
+        def parse_energy(line):
+            return float(line.rsplit('=', 2)[1]) * Hartree
+
     for line in fd:
         if 'cartesian coordinates (angstrom) at end' in line:
             positions = read_array(fd, natoms)
@@ -396,13 +421,19 @@ def read_abinit_out(fd):
         if 'Cartesian components of stress tensor (hartree/bohr^3)' in line:
             results['stress'] = read_stress(fd)
 
-        if 'Components of total free energy (in Hartree)' in line:
+        if line.strip() == energy_header:
+            # Header not to be confused with EnergyTermsDC,
+            # therefore we don't use .startswith()
+            energy = None
             for line in fd:
-                if 'Etotal' in line:
-                    energy = float(line.rsplit('=', 2)[1]) * Hartree
-                    results['energy'] = results['free_energy'] = energy
+                # Which of the listed energies should we include?
+                if total_energy_name in line:
+                    energy = parse_energy(line)
                     break
-                    # Which of the listed energies do we take ??
+            if energy is None:
+                raise RuntimeError('No energy found in output')
+            results['energy'] = results['free_energy'] = energy
+
         if 'END DATASET(S)' in line:
             break
 
@@ -419,11 +450,20 @@ def read_abinit_out(fd):
     return results
 
 
-def read_eigenvalues_for_one_spin(fd, nkpts):
+def match_kpt_header(line):
     headerpattern = (r'\s*kpt#\s*\S+\s*'
                      r'nband=\s*(\d+),\s*'
-                     r'wtk=([^,]+),\s*'
-                     r'kpt=\s*(\S)+\s*(\S+)\s*(\S+)')
+                     r'wtk=\s*(\S+?),\s*'
+                     r'kpt=\s*(\S+)+\s*(\S+)\s*(\S+)')
+    m = re.match(headerpattern, line)
+    assert m is not None, line
+    nbands = int(m.group(1))
+    weight = float(m.group(2))
+    kvector = np.array(m.group(3, 4, 5)).astype(float)
+    return nbands, weight, kvector
+
+
+def read_eigenvalues_for_one_spin(fd, nkpts):
 
     kpoint_weights = []
     kpoint_coords = []
@@ -431,13 +471,9 @@ def read_eigenvalues_for_one_spin(fd, nkpts):
     eig_kn = []
     for ikpt in range(nkpts):
         header = next(fd)
-        m = re.match(headerpattern, header)
-        assert m is not None, header
-        nbands = int(m.group(1))
-        weight = float(m.group(2))
-        kvector = np.array(m.group(3, 4, 5)).astype(float)
+        nbands, weight, kvector = match_kpt_header(header)
         kpoint_coords.append(kvector)
-        kpoint_weights.append(float(weight))
+        kpoint_weights.append(weight)
 
         eig_n = []
         while len(eig_n) < nbands:
@@ -459,12 +495,12 @@ def read_eig(fd):
     line = next(fd)
     results = {}
     m = re.match(r'\s*Fermi \(or HOMO\) energy \(hartree\)\s*=\s*(\S+)', line)
-    assert m is not None
-    results['fermilevel'] = float(m.group(1)) * Hartree
+    if m is not None:
+        results['fermilevel'] = float(m.group(1)) * Hartree
+        line = next(fd)
 
     nspins = 1
 
-    line = next(fd)
     m = re.match(r'\s*Magnetization \(Bohr magneton\)=\s*(\S+)', line)
     if m is not None:
         nspins = 2
@@ -510,11 +546,12 @@ def read_eig(fd):
 
 def write_files_file(fd, label, ppp_list):
     """Write files-file, the file which tells abinit about other files."""
-    fd.write('%s\n' % (label + '.in'))  # input
-    fd.write('%s\n' % (label + '.txt'))  # output
-    fd.write('%s\n' % (label + 'i'))  # input
-    fd.write('%s\n' % (label + 'o'))  # output
-    fd.write('%s\n' % (label + '.abinit'))
+    prefix = label.rsplit('/', 1)[-1]
+    fd.write('%s\n' % (prefix + '.in'))  # input
+    fd.write('%s\n' % (prefix + '.txt'))  # output
+    fd.write('%s\n' % (prefix + 'i'))  # input
+    fd.write('%s\n' % (prefix + 'o'))  # output
+    fd.write('%s\n' % (prefix + '.abinit'))
     # Provide the psp files
     for ppp in ppp_list:
         fd.write('%s\n' % (ppp))  # psp file path
@@ -524,10 +561,29 @@ def get_default_abinit_pp_paths():
     return os.environ.get('ABINIT_PP_PATH', '.').split(':')
 
 
+abinit_input_version_warning = """\
+Abinit input format has changed in Abinit9.
+
+ASE will currently write inputs for Abinit8 by default.  Please
+silence this warning passing either Abinit(v8_legacy_format=True) to
+write the old Abinit8 format, or False for writing
+the new Abinit9+ format.
+
+The default will change to Abinit9+ format from ase-3.22, and this
+warning will be removed.
+
+Please note that stdin to Abinit should be the .files file until version 8
+but the main inputfile (conventionally abinit.in) from abinit9,
+which may require reconfiguring the ASE/Abinit shell command.
+"""
+
+
+
 def write_all_inputs(atoms, properties, parameters,
                      pp_paths=None,
                      raise_exception=True,
-                     label='abinit'):
+                     label='abinit',
+                     *, v8_legacy_format=True):
     species = sorted(set(atoms.numbers))
     if pp_paths is None:
         pp_paths = get_default_abinit_pp_paths()
@@ -537,19 +593,33 @@ def write_all_inputs(atoms, properties, parameters,
                        pps=parameters.pps,
                        search_paths=pp_paths)
 
-    with open(label + '.files', 'w') as fd:
-        write_files_file(fd, label, ppp)
+    if v8_legacy_format is None:
+        warnings.warn(abinit_input_version_warning,
+                      FutureWarning)
+        v8_legacy_format = True
+
+    if v8_legacy_format:
+        with open(label + '.files', 'w') as fd:
+            write_files_file(fd, label, ppp)
+        pseudos = None
+
+        # XXX here we build the txt filename again, which is bad
+        # (also defined in the calculator)
+        output_filename = label + '.txt'
+    else:
+        pseudos = ppp  # Include pseudopotentials in inputfile
+        output_filename = label + '.abo'
 
     # Abinit will write to label.txtA if label.txt already exists,
     # so we remove it if it's there:
-    filename = label + '.txt'
-    if os.path.isfile(filename):
-        os.remove(filename)
+    if os.path.isfile(output_filename):
+        os.remove(output_filename)
 
     parameters.write(label + '.ase')
 
     with open(label + '.in', 'w') as fd:
-        write_abinit_in(fd, atoms, param=parameters, species=species)
+        write_abinit_in(fd, atoms, param=parameters, species=species,
+                        pseudos=pseudos)
 
 
 def read_ase_and_abinit_inputs(label):
@@ -559,10 +629,10 @@ def read_ase_and_abinit_inputs(label):
     return atoms, parameters
 
 
-def read_results(label):
-    filename = label + '.txt'
+def read_results(label, textfilename):
+    # filename = label + '.txt'
     results = {}
-    with open(filename) as fd:
+    with open(textfilename) as fd:
         dct = read_abinit_out(fd)
         results.update(dct)
     # The eigenvalues section in the main file is shortened to
@@ -630,6 +700,11 @@ def get_ppp_list(atoms, species, raise_exception, xc, pps,
                     # warning: see download.sh in
                     # abinit-pseudopotentials*tar.gz for additional
                     # information!
+                    #
+                    # XXXX This is probably buggy, max(filenames) uses
+                    # an lexicographic order so 14 < 8, and it's
+                    # untested so if I change it I'm sure things will
+                    # just be inconsistent.  --askhl
                     filenames[0] = max(filenames)  # Semicore or hard
                 elif pps == 'hgh':
                     # Lowest valence electron count
