@@ -15,6 +15,7 @@ from ase.parallel import paropen
 from ase.spacegroup import Spacegroup
 from ase.geometry.cell import cellpar_to_cell
 from ase.constraints import FixAtoms, FixedPlane, FixedLine, FixCartesian
+from ase.utils import atoms_to_spglib_cell
 
 # independent unit management included here:
 # When high accuracy is required, this allows to easily pin down
@@ -631,16 +632,12 @@ def read_castep_cell(fd, index=None, calculator_args={}, find_spg=False,
         try:
             import spglib
         except ImportError:
-            try:
-                from pyspglib import spglib
-            except ImportError:
-                # spglib is not present
-                warnings.warn('spglib not found installed on this system - '
-                              'automatic spacegroup detection is not possible')
-                spglib = None
+            warnings.warn('spglib not found installed on this system - '
+                          'automatic spacegroup detection is not possible')
+            spglib = None
 
         if spglib is not None:
-            symmd = spglib.get_symmetry_dataset(atoms)
+            symmd = spglib.get_symmetry_dataset(atoms_to_spglib_cell(atoms))
             atoms_spg = Spacegroup(int(symmd['number']))
             atoms.info['spacegroup'] = atoms_spg
 
