@@ -1,14 +1,23 @@
 import numpy as np
 from ase.atoms import Atoms
+from ase.utils import reader, writer
 
 
-def read_dftb(filename='dftb_in.hsd'):
-    """Method to read coordinates form DFTB+ input file dftb_in.hsd
-    additionally read information about fixed atoms
-    and periodic boundary condition
+@reader
+def read_dftb(fd):
+    """Method to read coordinates from the Geometry section
+    of a DFTB+ input file (typically called "dftb_in.hsd").
+
+    As described in the DFTB+ manual, this section can be
+    in a number of different formats. This reader supports
+    the GEN format and the so-called "explicit" format.
+
+    The "explicit" format is unique to DFTB+ input files.
+    The GEN format can also be used in a stand-alone fashion,
+    as coordinate files with a `.gen` extension. Reading and
+    writing such files is implemented in `ase.io.gen`.
     """
-    with open(filename, 'r') as myfile:
-        lines = myfile.readlines()
+    lines = fd.readlines()
 
     atoms_pos = []
     atom_symbols = []
@@ -18,16 +27,18 @@ def read_dftb(filename='dftb_in.hsd'):
     mycell = []
 
     for iline, line in enumerate(lines):
-        if (line.strip().startswith('#')):
+        if line.strip().startswith('#'):
             pass
-        elif ('genformat') in line.lower():
+        elif 'genformat' in line.lower():
             natoms = int(lines[iline + 1].split()[0])
             if lines[iline + 1].split()[1].lower() == 's':
                 my_pbc = True
             elif lines[iline + 1].split()[1].lower() == 'f':
                 my_pbc = True
                 fractional = True
+
             symbols = lines[iline + 2].split()
+
             for i in range(natoms):
                 index = iline + 3 + i
                 aindex = int(lines[index].split()[1]) - 1
@@ -35,20 +46,21 @@ def read_dftb(filename='dftb_in.hsd'):
 
                 position = [float(p) for p in lines[index].split()[2:]]
                 atoms_pos.append(position)
+
             if my_pbc:
                 for i in range(3):
                     index = iline + 4 + natoms + i
                     cell = [float(c) for c in lines[index].split()]
                     mycell.append(cell)
         else:
-            if ('TypeNames' in line):
+            if 'TypeNames' in line:
                 col = line.split()
                 for i in range(3, len(col) - 1):
                     type_names.append(col[i].strip("\""))
-            elif ('Periodic' in line):
-                if ('Yes' in line):
+            elif 'Periodic' in line:
+                if 'Yes' in line:
                     my_pbc = True
-            elif ('LatticeVectors' in line):
+            elif 'LatticeVectors' in line:
                 for imycell in range(3):
                     extraline = lines[iline + imycell + 1]
                     cols = extraline.split()
@@ -58,21 +70,21 @@ def read_dftb(filename='dftb_in.hsd'):
                 pass
 
     if not my_pbc:
-        mycell = [1.0, 1.0, 1.0]
+        mycell = [0.] * 3
 
     start_reading_coords = False
     stop_reading_coords = False
     for line in lines:
-        if (line.strip().startswith('#')):
+        if line.strip().startswith('#'):
             pass
         else:
-            if ('TypesAndCoordinates' in line):
+            if 'TypesAndCoordinates' in line:
                 start_reading_coords = True
             if start_reading_coords:
-                if ('}' in line):
+                if '}' in line:
                     stop_reading_coords = True
-            if (start_reading_coords and not (stop_reading_coords)
-               and 'TypesAndCoordinates' not in line):
+            if (start_reading_coords and not stop_reading_coords
+                and 'TypesAndCoordinates' not in line):
                 typeindexstr, xxx, yyy, zzz = line.split()[:4]
                 typeindex = int(typeindexstr)
                 symbol = type_names[typeindex - 1]
@@ -96,9 +108,9 @@ def read_dftb_velocities(atoms, filename='geo_end.xyz'):
     # AA/ps -> ase units
     AngdivPs2ASE = 1.0 / (1e-12 * second)
 
-    myfile = open(filename)
+    with open(filename) as fd:
+        lines = fd.readlines()
 
-    lines = myfile.readlines()
     # remove empty lines
     lines_ok = []
     for line in lines:
@@ -118,13 +130,11 @@ def read_dftb_velocities(atoms, filename='geo_end.xyz'):
     return atoms
 
 
-def read_dftb_lattice(fileobj='md.out', images=None):
+@reader
+def read_dftb_lattice(fileobj, images=None):
     """Read lattice vectors from MD and return them as a list.
 
     If a molecules are parsed add them there."""
-    if isinstance(fileobj, str):
-        fileobj = open(fileobj)
-
     if images is not None:
         append = True
         if hasattr(images, 'get_positions'):
@@ -161,6 +171,14 @@ def read_dftb_lattice(fileobj='md.out', images=None):
         return lattices
 
 
+@writer
+def write_dftb(fileobj, images):
+    """Write structure in GEN format (refer to DFTB+ manual).
+       Multiple snapshots are not allowed. """
+    from ase.io.gen import write_gen
+    write_gen(fileobj, images)
+
+
 def write_dftb_velocities(atoms, filename='velocities.txt'):
     """Method to write velocities (in atomic units) from ASE
        to a file to be read by dftb+
@@ -169,75 +187,10 @@ def write_dftb_velocities(atoms, filename='velocities.txt'):
     # ase units -> atomic units
     ASE2au = Bohr / AUT
 
-    if isinstance(filename, str):
-        myfile = open(filename, 'w')
-    else:
-        # Assume it's a 'file-like object'
-        myfile = filename
-
-    velocities = atoms.get_velocities()
-    for velocity in velocities:
-        myfile.write(' %19.16f %19.16f %19.16f \n'
+    with open(filename, 'w') as fd:
+        velocities = atoms.get_velocities()
+        for velocity in velocities:
+            fd.write(' %19.16f %19.16f %19.16f \n'
                      % (velocity[0] / ASE2au,
                         velocity[1] / ASE2au,
                         velocity[2] / ASE2au))
-
-    return
-
-
-def write_dftb(filename, atoms):
-    """Method to write atom structure in DFTB+ format
-       (gen format)
-    """
-
-    # sort
-    atoms.set_masses()
-    masses = atoms.get_masses()
-    indexes = np.argsort(masses)
-    atomsnew = Atoms()
-    for i in indexes:
-        atomsnew = atomsnew + atoms[i]
-
-    if isinstance(filename, str):
-        myfile = open(filename, 'w')
-    else:
-        # Assume it's a 'file-like object'
-        myfile = filename
-
-    ispbc = atoms.get_pbc()
-    box = atoms.get_cell()
-
-    if (any(ispbc)):
-        myfile.write('%8d %2s \n' % (len(atoms), 'S'))
-    else:
-        myfile.write('%8d %2s \n' % (len(atoms), 'C'))
-
-    chemsym = atomsnew.get_chemical_symbols()
-    allchem = ''
-    for i in chemsym:
-        if i not in allchem:
-            allchem = allchem + i + ' '
-    myfile.write(allchem + ' \n')
-
-    coords = atomsnew.get_positions()
-    itype = 1
-    for iatom, coord in enumerate(coords):
-        if iatom > 0:
-            if chemsym[iatom] != chemsym[iatom - 1]:
-                itype = itype + 1
-        myfile.write('%5i%5i  %19.16f %19.16f %19.16f \n'
-                     % (iatom + 1, itype,
-                        coords[iatom][0], coords[iatom][1], coords[iatom][2]))
-    # write box
-    if (any(ispbc)):
-        # dftb dummy
-        myfile.write(' %19.16f %19.16f %19.16f \n' % (0, 0, 0))
-        myfile.write(' %19.16f %19.16f %19.16f \n'
-                     % (box[0][0], box[0][1], box[0][2]))
-        myfile.write(' %19.16f %19.16f %19.16f \n'
-                     % (box[1][0], box[1][1], box[1][2]))
-        myfile.write(' %19.16f %19.16f %19.16f \n'
-                     % (box[2][0], box[2][1], box[2][2]))
-
-    if isinstance(filename, str):
-        myfile.close()
