@@ -63,7 +63,6 @@ def object_hook(dct):
     return dct
 
 
-
 def create_ndarray(shape, dtype, data):
     """Create ndarray from shape, dtype and flattened data."""
     array = np.empty(shape, dtype=dtype)
@@ -80,12 +79,10 @@ def create_ase_object(objtype, dct):
     # We can formalize this later if it ever becomes necessary.
     if objtype == 'cell':
         from ase.cell import Cell
-        pbc = dct.pop('pbc')
+        dct.pop('pbc', None)  # compatibility; we once had pbc
         obj = Cell(**dct)
-        if pbc is not None:
-            obj._pbc = pbc
     elif objtype == 'bandstructure':
-        from ase.dft.band_structure import BandStructure
+        from ase.spectrum.band_structure import BandStructure
         obj = BandStructure(**dct)
     elif objtype == 'bandpath':
         from ase.dft.kpoints import BandPath
@@ -104,19 +101,30 @@ mydecode = json.JSONDecoder(object_hook=object_hook).decode
 
 
 def intkey(key):
+    """Convert str to int if possible."""
     try:
         return int(key)
     except ValueError:
         return key
 
 
+def fix_int_keys_in_dicts(obj):
+    """Convert "int" keys: "1" -> 1.
+
+    The json.dump() function will convert int keys in dicts to str keys.
+    This function goes the other way.
+    """
+    if isinstance(obj, dict):
+        return {intkey(key): fix_int_keys_in_dicts(value)
+                for key, value in obj.items()}
+    return obj
+
+
 def numpyfy(obj):
     if isinstance(obj, dict):
         if '__complex_ndarray__' in obj:
             r, i = (np.array(x) for x in obj['__complex_ndarray__'])
             return r + i * 1j
-        return dict((intkey(key), numpyfy(value))
-                    for key, value in obj.items())
     if isinstance(obj, list) and len(obj) > 0:
         try:
             a = np.array(obj)
@@ -131,6 +139,7 @@ def numpyfy(obj):
 
 def decode(txt, always_array=True):
     obj = mydecode(txt)
+    obj = fix_int_keys_in_dicts(obj)
     if always_array:
         obj = numpyfy(obj)
     return obj
