@@ -276,7 +276,7 @@ class NetCDFTrajectory:
             self._add_velocities()
             self._get_variable(self._velocities_var)[i] = \
                 atoms.get_momenta() / atoms.get_masses().reshape(-1, 1)
-        a, b, c, alpha, beta, gamma = atoms.get_cell_lengths_and_angles()
+        a, b, c, alpha, beta, gamma = atoms.cell.cellpar()
         if np.any(np.logical_not(atoms.pbc)):
             warnings.warn('Atoms have nonperiodic directions. Cell lengths in '
                           'these directions are lost and will be '
@@ -328,14 +328,10 @@ class NetCDFTrajectory:
         self._close()
 
     def _define_file_structure(self, atoms):
-        if not hasattr(self.nc, 'Conventions'):
-            self.nc.Conventions = 'AMBER'
-        if not hasattr(self.nc, 'ConventionVersion'):
-            self.nc.ConventionVersion = '1.0'
-        if not hasattr(self.nc, 'program'):
-            self.nc.program = 'ASE'
-        if not hasattr(self.nc, 'programVersion'):
-            self.nc.programVersion = ase.__version__
+        self.nc.Conventions = 'AMBER'
+        self.nc.ConventionVersion = '1.0'
+        self.nc.program = 'ASE'
+        self.nc.programVersion = ase.__version__
 
         if self._frame_dim not in self.nc.dimensions:
             self.nc.createDimension(self._frame_dim, None)
@@ -481,6 +477,12 @@ class NetCDFTrajectory:
                     data[index[sl]] = var[sl]
         return data
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, *args):
+        self.close()
+
     def close(self):
         """Close the trajectory file."""
         if self.nc is not None:
@@ -643,16 +645,14 @@ class NetCDFTrajectory:
 
 
 def read_netcdftrajectory(filename, index=-1):
-    traj = NetCDFTrajectory(filename, mode='r')
-    return traj[index]
+    with NetCDFTrajectory(filename, mode='r') as traj:
+        return traj[index]
 
 
 def write_netcdftrajectory(filename, images):
-    traj = NetCDFTrajectory(filename, mode='w')
-
     if hasattr(images, 'get_positions'):
         images = [images]
 
-    for atoms in images:
-        traj.write(atoms)
-    traj.close()
+    with NetCDFTrajectory(filename, mode='w') as traj:
+        for atoms in images:
+            traj.write(atoms)
