@@ -27,7 +27,7 @@ def _get_geom(atoms, **params):
             if pbci:
                 outpos[:, i] = scpos[:, i]
         npbc = pbc.sum()
-        cellpars = atoms.get_cell_lengths_and_angles()
+        cellpars = atoms.cell.cellpar()
         geom.append('  system {} units angstrom'.format(_system_type[npbc]))
         if npbc == 3:
             geom.append('    lattice_vectors')
@@ -297,7 +297,8 @@ def write_nwchem_in(fd, atoms, properties=None, **params):
     scratch = os.path.abspath(params.pop('scratch', label))
     restart_kw = params.get('restart_kw','start')
     if restart_kw not in ('start','restart'):
-       raise ValueError("Unrecognised restart keyword: {}!".format(restart_kw))
+        raise ValueError("Unrecognised restart keyword: {}!"
+                         .format(restart_kw))
     short_label = label.rsplit('/', 1)[-1]
     out = ['title "{}"'.format(short_label),
            'permanent_dir {}'.format(perm),
