@@ -3,12 +3,11 @@
 See https://en.wikipedia.org/wiki/Chemical_table_file#SDF
 """
 from ase.atoms import Atoms
+from ase.utils import reader
 
 
+@reader
 def read_sdf(fileobj):
-    if isinstance(fileobj, str):
-        fileobj = open(fileobj)
-
     lines = fileobj.readlines()
     # first three lines header
     del lines[:3]
