@@ -107,7 +107,8 @@ class TrajectoryWriter:
         if self.master:
             self.backend = ulm.open(filename, mode, tag='ASE-Trajectory')
             if len(self.backend) > 0 and mode == 'a':
-                atoms = Trajectory(filename)[0]
+                with Trajectory(filename) as traj:
+                    atoms = traj[0]
                 self.header_data = get_header_data(atoms)
         else:
             self.backend = ulm.DummyWriter()
@@ -152,7 +153,7 @@ class TrajectoryWriter:
 
         write_atoms(b, atoms, write_header=write_header)
 
-        calc = atoms.get_calculator()
+        calc = atoms.calc
 
         if calc is None and len(kwargs) > 0:
             calc = SinglePointCalculator(atoms)
@@ -179,6 +180,7 @@ class TrajectoryWriter:
                                                   allow_calculation=False)
                         except (PropertyNotImplementedError, KeyError):
                             # KeyError is needed for Jacapo.
+                            # XXX We can perhaps remove this.
                             x = None
                 if x is not None:
                     if prop in ['stress', 'dipole']:
@@ -276,7 +278,7 @@ class TrajectoryReader:
 
             if 'parameters' in c:
                 calc.parameters.update(c.parameters)
-            atoms.set_calculator(calc)
+            atoms.calc = calc
 
         return atoms
 
@@ -338,7 +340,8 @@ def read_atoms(backend,
             return read_atoms(backend, header, traj, False)
         except Exception as ex:
             from distutils.version import LooseVersion
-            if LooseVersion(__version__) < traj.ase_version:
+            if (traj is not None and
+                LooseVersion(__version__) < traj.ase_version):
                 msg = ('You are trying to read a trajectory file written ' +
                        'with ASE-{v1} from ASE-{v2}. ' +
                        'It might help to update your ASE').format(
