@@ -3,5 +3,6 @@
 from ase.md.logger import MDLogger
 from ase.md.verlet import VelocityVerlet
 from ase.md.langevin import Langevin
+from ase.md.andersen import Andersen
 
-__all__ = ['MDLogger', 'VelocityVerlet', 'Langevin']
+__all__ = ['MDLogger', 'VelocityVerlet', 'Langevin', 'Andersen']
