@@ -1,5 +1,6 @@
 """Logging for molecular dynamics."""
 
+import os
 import weakref
 import sys
 import ase.units as units
@@ -22,11 +23,12 @@ class MDLogger:
 
     mode="a":      How the file is opened if logfile is a filename.
     """
+
     def __init__(self, dyn, atoms, logfile, header=True, stress=False,
                  peratom=False, mode="a"):
         import ase.parallel
         if ase.parallel.world.rank > 0:
-            logfile="/dev/null"  # Only log on master
+            logfile = os.devnull  # Only log on master
         if hasattr(dyn, "get_time"):
             self.dyn = weakref.proxy(dyn)
         else:
@@ -66,20 +68,27 @@ class MDLogger:
                 digits = 2
             else:
                 digits = 1
-            self.fmt += 3*("%%12.%df " % (digits,)) + " %6.1f"
+            self.fmt += 3 * ("%%12.%df " % (digits,)) + " %6.1f"
         if self.stress:
             self.hdr += "      ---------------------- stress [GPa] -----------------------"
-            self.fmt += 6*" %10.3f"
+            self.fmt += 6 * " %10.3f"
         self.fmt += "\n"
         if header:
-            self.logfile.write(self.hdr+"\n")
+            self.logfile.write(self.hdr + "\n")
 
     def __del__(self):
         self.close()
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, *args):
+        self.close()
+
     def close(self):
-        if self.ownlogfile:
+        if self.ownlogfile and self.logfile is not None:
             self.logfile.close()
+            self.logfile = None
 
     def __call__(self):
         epot = self.atoms.get_potential_energy()
@@ -90,13 +99,12 @@ class MDLogger:
             epot /= global_natoms
             ekin /= global_natoms
         if self.dyn is not None:
-            t = self.dyn.get_time() / (1000*units.fs)
+            t = self.dyn.get_time() / (1000 * units.fs)
             dat = (t,)
         else:
             dat = ()
-        dat += (epot+ekin, epot, ekin, temp)
+        dat += (epot + ekin, epot, ekin, temp)
         if self.stress:
             dat += tuple(self.atoms.get_stress(include_ideal_gas=True) / units.GPa)
         self.logfile.write(self.fmt % dat)
         self.logfile.flush()
-
