@@ -2,7 +2,7 @@
 # towards replacing ase.dft.dos and ase.dft.pdos
 from abc import ABCMeta, abstractmethod
 import warnings
-from typing import Any, Dict, Sequence, Tuple, TypeVar
+from typing import Any, Dict, Sequence, Tuple, TypeVar, Union
 
 import numpy as np
 from ase.utils.plotting import SimplePlottingAxes
@@ -41,12 +41,15 @@ class DOSData(metaclass=ABCMeta):
     def copy(self) -> 'DOSData':
         """Returns a copy in which info dict can be safely mutated"""
 
-    def sample(self,
-               energies: Sequence[float],
-               width: float = 0.1,
-               smearing: str = 'Gauss') -> np.ndarray:
+    def _sample(self,
+                energies: Sequence[float],
+                width: float = 0.1,
+                smearing: str = 'Gauss') -> np.ndarray:
         """Sample the DOS data at chosen points, with broadening
 
+        Note that no correction is made here for the sampling bin width; total
+        intensity will vary with sampling density.
+
         Args:
             energies: energy values for sampling
             width: Width of broadening kernel
@@ -58,30 +61,30 @@ class DOSData(metaclass=ABCMeta):
         """
 
         self._check_positive_width(width)
-        weights_grid = np.dot(
-            self.get_weights(),
-            self._delta(np.asarray(energies),
-                        np.asarray(self.get_energies())[:, np.newaxis],
-                        width,
-                        smearing=smearing))
+        weights_grid = np.zeros(len(energies), float)
+        weights = self.get_weights()
+        energies = np.asarray(energies, float)
+
+        for i, raw_energy in enumerate(self.get_energies()):
+            delta = self._delta(energies, raw_energy, width, smearing=smearing)
+            weights_grid += weights[i] * delta
         return weights_grid
 
     def _almost_equals(self, other: Any) -> bool:
         """Compare with another DOSData for testing purposes"""
         if not isinstance(other, type(self)):
             return False
-        elif not self.info == other.info:
+        if self.info != other.info:
             return False
-        elif not np.allclose(self.get_weights(), other.get_weights()):
+        if not np.allclose(self.get_weights(), other.get_weights()):
             return False
-        else:
-            return np.allclose(self.get_energies(), other.get_energies())
+        return np.allclose(self.get_energies(), other.get_energies())
 
     @staticmethod
     def _delta(x: np.ndarray,
-               x0: np.ndarray,
+               x0: float,
                width: float,
-               smearing: str = 'Gauss') -> Sequence[Sequence[float]]:
+               smearing: str = 'Gauss') -> np.ndarray:
         """Return a delta-function centered at 'x0'.
 
         This function is used with numpy broadcasting; if x is a row and x0 is
@@ -109,7 +112,7 @@ class DOSData(metaclass=ABCMeta):
                     padding: float = 3,
                     width: float = 0.1,
                     smearing: str = 'Gauss',
-                    ) -> Tuple[Sequence[float], Sequence[float]]:
+                    ) -> 'GridDOSData':
         """Sample the DOS data on an evenly-spaced energy grid
 
         Args:
@@ -118,8 +121,9 @@ class DOSData(metaclass=ABCMeta):
             xmax: Maximum sampled x value; if unspecified, a default is chosen
             padding: If xmin/xmax is unspecified, default value will be padded
                 by padding * width to avoid cutting off peaks.
-            width: Width of broadening kernel, passed to self.sample()
-            smearing: selection of broadening kernel, passed to self.sample()
+            width: Width of broadening kernel
+            smearing: selection of broadening kernel (only 'Gauss' is
+                implemented)
 
         Returns:
             (energy values, sampled DOS)
@@ -129,19 +133,22 @@ class DOSData(metaclass=ABCMeta):
             xmin = min(self.get_energies()) - (padding * width)
         if xmax is None:
             xmax = max(self.get_energies()) + (padding * width)
-        energies = np.linspace(xmin, xmax, npts)
-        return energies, self.sample(energies, width=width, smearing=smearing)
+        energies_grid = np.linspace(xmin, xmax, npts)
+        weights_grid = self._sample(energies_grid, width=width,
+                                    smearing=smearing)
 
-    def plot_dos(self,
-                 npts: int = 1000,
-                 xmin: float = None,
-                 xmax: float = None,
-                 width: float = 0.1,
-                 smearing: str = 'Gauss',
-                 ax: 'matplotlib.axes.Axes' = None,
-                 show: bool = False,
-                 filename: str = None,
-                 mplargs: dict = None) -> 'matplotlib.axes.Axes':
+        return GridDOSData(energies_grid, weights_grid, info=self.info.copy())
+
+    def plot(self,
+             npts: int = 1000,
+             xmin: float = None,
+             xmax: float = None,
+             width: float = 0.1,
+             smearing: str = 'Gauss',
+             ax: 'matplotlib.axes.Axes' = None,
+             show: bool = False,
+             filename: str = None,
+             mplargs: dict = None) -> 'matplotlib.axes.Axes':
         """Simple 1-D plot of DOS data, resampled onto a grid
 
         If the special key 'label' is present in self.info, this will be set
@@ -151,8 +158,8 @@ class DOSData(metaclass=ABCMeta):
 
         Args:
             npts, xmin, xmax: output data range, as passed to self.sample_grid
-            width: Width of broadening kernel, passed to self.sample()
-            smearing: selection of broadening kernel, passed to self.sample()
+            width: Width of broadening kernel for self.sample_grid()
+            smearing: selection of broadening kernel for self.sample_grid()
             ax: existing Matplotlib axes object. If not provided, a new figure
                 with one set of axes will be created using Pyplot
             show: show the figure on-screen
@@ -165,19 +172,17 @@ class DOSData(metaclass=ABCMeta):
             Plotting axes. If "ax" was set, this is the same object.
         """
 
-        with SimplePlottingAxes(ax=ax, show=show, filename=filename) as ax:
+        if mplargs is None:
+            mplargs = {}
+        if 'label' not in mplargs:
+            mplargs.update({'label': self.label_from_info(self.info)})
 
-            if mplargs is None:
-                mplargs = {}
-            if 'label' not in mplargs:
-                mplargs.update({'label': self.label_from_info(self.info)})
-
-            energies, intensity = self.sample_grid(npts, xmin=xmin, xmax=xmax,
-                                                   width=width,
-                                                   smearing=smearing)
-            ax.plot(energies, intensity, **mplargs)
-
-        return ax
+        return self.sample_grid(npts, xmin=xmin, xmax=xmax,
+                                width=width,
+                                smearing=smearing
+                                ).plot(ax=ax, xmin=xmin, xmax=xmax,
+                                       show=show, filename=filename,
+                                       mplargs=mplargs)
 
     @staticmethod
     def label_from_info(info: Dict[str, str]):
@@ -232,7 +237,7 @@ class RawDOSData(GeneralDOSData):
     This is an appropriate data container for density-of-states (DOS) or
     spectral data where the energy data values not form a known regular
     grid. The data may be plotted or resampled for further analysis using the
-    sample(), sample_grid() and plot() methods. Multiple weights at the same
+    sample_grid() and plot() methods. Multiple weights at the same
     energy value will *only* be combined in output data, and data stored in
     RawDOSData is never resampled. A plot_deltas() function is also provided
     which plots the raw data.
@@ -296,11 +301,11 @@ class RawDOSData(GeneralDOSData):
         Returns:
             Plotting axes. If "ax" was set, this is the same object.
         """
+
+        if mplargs is None:
+            mplargs = {}
+
         with SimplePlottingAxes(ax=ax, show=show, filename=filename) as ax:
-
-            if mplargs is None:
-                mplargs = {}
-
             ax.vlines(self.get_energies(), 0, self.get_weights(), **mplargs)
 
         return ax
@@ -310,11 +315,11 @@ class GridDOSData(GeneralDOSData):
     """A collection of regularly-sampled data which represents a DOS
 
     This is an appropriate data container for density-of-states (DOS) or
-    spectral data where the intensity values form a regular grid. This is
-    generally the result of sampling or integrating into discrete bins,
-    rather than a collection of unique states. The data may be plotted or
-    resampled for further analysis using the sample(), sample_grid() and plot()
-    methods.
+    spectral data where the intensity values form a regular grid. This
+    is generally the result of sampling or integrating into discrete
+    bins, rather than a collection of unique states. The data may be
+    plotted or resampled for further analysis using the sample_grid()
+    and plot() methods.
 
     Metadata may be stored in the info dict, in which keys and values must be
     strings. This data is used for selecting and combining multiple DOSData
@@ -354,20 +359,22 @@ class GridDOSData(GeneralDOSData):
         super().__init__(energies, weights, info=info)
         self.sigma_cutoff = 3
 
-    def _check_spacing(self, width):
+    def _check_spacing(self, width) -> float:
         current_spacing = self._data[0, 1] - self._data[0, 0]
         if width < (2 * current_spacing):
             warnings.warn(
                 "The broadening width is small compared to the original "
                 "sampling density. The results are unlikely to be smooth.")
+        return current_spacing
 
-    def sample(self,
-               energies: Sequence[float],
-               width: float = 0.1,
-               smearing: str = 'Gauss') -> np.ndarray:
-        self._check_spacing(width)
-        return super().sample(energies=energies,
-                              width=width, smearing=smearing)
+    def _sample(self,
+                energies: Sequence[float],
+                width: float = 0.1,
+                smearing: str = 'Gauss') -> np.ndarray:
+        current_spacing = self._check_spacing(width)
+        return super()._sample(energies=energies,
+                               width=width, smearing=smearing
+                               ) * current_spacing
 
     def __add__(self, other: 'GridDOSData') -> 'GridDOSData':
         # This method uses direct access to the mutable energy and weights data
@@ -396,16 +403,34 @@ class GridDOSData(GeneralDOSData):
                                  info=new_info)
         return new_object
 
-    def plot_dos(self,
-                 npts: int = 0,
-                 xmin: float = None,
-                 xmax: float = None,
-                 width: float = 0.1,
-                 smearing: str = 'Gauss',
-                 ax: 'matplotlib.axes.Axes' = None,
-                 show: bool = False,
-                 filename: str = None,
-                 mplargs: dict = None) -> 'matplotlib.axes.Axes':
+    @staticmethod
+    def _interpret_smearing_args(npts: int,
+                                 width: float = None,
+                                 default_npts: int = 1000,
+                                 default_width: float = 0.1
+                                 ) -> Tuple[int, Union[float, None]]:
+        """Figure out what the user intended: resample if width provided"""
+        if width is not None:
+            if npts:
+                return (npts, float(width))
+            else:
+                return (default_npts, float(width))
+        else:
+            if npts:
+                return (npts, default_width)
+            else:
+                return (0, None)
+
+    def plot(self,
+             npts: int = 0,
+             xmin: float = None,
+             xmax: float = None,
+             width: float = None,
+             smearing: str = 'Gauss',
+             ax: 'matplotlib.axes.Axes' = None,
+             show: bool = False,
+             filename: str = None,
+             mplargs: dict = None) -> 'matplotlib.axes.Axes':
         """Simple 1-D plot of DOS data
 
         Data will be resampled onto a grid with `npts` points unless `npts` is
@@ -423,8 +448,9 @@ class GridDOSData(GeneralDOSData):
 
         Args:
             npts, xmin, xmax: output data range, as passed to self.sample_grid
-            width: Width of broadening kernel, passed to self.sample()
-            smearing: selection of broadening kernel, passed to self.sample()
+            width: Width of broadening kernel, passed to self.sample_grid().
+                If no npts was set but width is set, npts will be set to 1000.
+            smearing: selection of broadening kernel for self.sample_grid()
             ax: existing Matplotlib axes object. If not provided, a new figure
                 with one set of axes will be created using Pyplot
             show: show the figure on-screen
@@ -436,20 +462,24 @@ class GridDOSData(GeneralDOSData):
             Plotting axes. If "ax" was set, this is the same object.
         """
 
+        npts, width = self._interpret_smearing_args(npts, width)
+
+        if mplargs is None:
+            mplargs = {}
+        if 'label' not in mplargs:
+            mplargs.update({'label': self.label_from_info(self.info)})
+
+        if npts:
+            assert isinstance(width, float)
+            dos = self.sample_grid(npts, xmin=xmin,
+                                   xmax=xmax, width=width,
+                                   smearing=smearing)
+        else:
+            dos = self
+
+        energies, intensity = dos.get_energies(), dos.get_weights()
+
         with SimplePlottingAxes(ax=ax, show=show, filename=filename) as ax:
-
-            if mplargs is None:
-                mplargs = {}
-            if 'label' not in mplargs:
-                mplargs.update({'label': self.label_from_info(self.info)})
-
-            if npts:
-                energies, intensity = self.sample_grid(npts, xmin=xmin,
-                                                       xmax=xmax, width=width,
-                                                       smearing=smearing)
-            else:
-                energies, intensity = self.get_energies(), self.get_weights()
-
             ax.plot(energies, intensity, **mplargs)
             ax.set_xlim(left=xmin, right=xmax)
 
