@@ -30,3 +30,10 @@ def test_atom():
     m += a
     del m[:1]
     print(m)
+
+
+def test_repr():
+    txt = repr(Atom('Si', charge=7))
+    print(txt)
+    assert 'Si' in txt
+    assert 'charge' in txt
