@@ -1,15 +1,16 @@
-def test_relax():
+import numpy as np
+from ase.cluster import Icosahedron
+from pytest import mark
+
+
+@mark.calculator_lite
+def test_relax(KIM):
     """
     Test that a static relaxation that requires multiple neighbor list
     rebuilds can be carried out successfully.  This is verified by relaxing
     an icosahedral cluster of atoms and checking that the relaxed energy
     matches a known precomputed value for an example model.
     """
-    import numpy as np
-    from ase.cluster import Icosahedron
-    from pytest import importorskip
-    importorskip('kimpy')
-    from ase.calculators.kim import KIM
     from ase.optimize import BFGS
 
     energy_ref = -0.56  # eV
