@@ -1,8 +1,9 @@
-def test_lammpslib_interface():
-    # test some functionality of the interace
-    import numpy as np
-    from ase.calculators.lammpslib import is_upper_triangular
+import numpy as np
+from ase.calculators.lammpslib import is_upper_triangular
 
+
+def test_lammpslib_interface():
+    """test some functionality of the interace"""
     m = np.ones((3, 3))
     assert not is_upper_triangular(m)
 
