@@ -9,7 +9,7 @@ def test_gulp_opt():
     atoms = molecule('H2O')
     atoms1 = atoms.copy()
     atoms1.calc = GULP(library='reaxff.lib')
-    opt1 = BFGS(atoms1,trajectory='bfgs.traj')
+    opt1 = BFGS(atoms1)
     opt1.run(fmax=0.005)
 
     atoms2 = atoms.copy()
@@ -23,9 +23,10 @@ def test_gulp_opt():
     # GULP optimization test using stress
     atoms = bulk('Au', 'bcc', a=2.7, cubic=True)
     atoms1 = atoms.copy()
-    atoms1.calc = GULP(keywords='conp gradient stress_out', library='reaxff_general.lib')
+    atoms1.calc = GULP(keywords='conp gradient stress_out',
+                       library='reaxff_general.lib')
     atoms1f = ExpCellFilter(atoms1)
-    opt1 = BFGS(atoms1f, trajectory='bfgs.traj')
+    opt1 = BFGS(atoms1f)
     opt1.run(fmax=0.005)
 
     atoms2 = atoms.copy()
