@@ -1,10 +1,11 @@
-def test_emt1():
-    from ase import Atoms
-    from ase.calculators.emt import EMT
-    from ase.constraints import FixBondLength
-    from ase.io import Trajectory
-    from ase.optimize import BFGS
+from ase import Atoms
+from ase.calculators.emt import EMT
+from ase.constraints import FixBondLength
+from ase.io import Trajectory
+from ase.optimize import BFGS
 
+
+def test_emt1():
     a = 3.6
     b = a / 2
     cu = Atoms('Cu2Ag',
@@ -17,15 +18,15 @@ def test_emt1():
 
     d0 = cu.get_distance(0, 1)
     cu.set_constraint(FixBondLength(0, 1))
-    t = Trajectory('cu2ag.traj', 'w', cu)
-    qn = BFGS(cu)
-    qn.attach(t.write)
-
 
     def f():
         print(cu.get_distance(0, 1))
 
+    qn = BFGS(cu)
+    with Trajectory('cu2ag.traj', 'w', cu) as t:
+        qn.attach(t.write)
+
+        qn.attach(f)
+        qn.run(fmax=0.001)
 
-    qn.attach(f)
-    qn.run(fmax=0.001)
     assert abs(cu.get_distance(0, 1) - d0) < 1e-14
