@@ -1,8 +1,8 @@
-def test_info():
-    from ase import Atoms
-    from ase.io import Trajectory
+from ase import Atoms
+from ase.io import Trajectory
 
-    # Create a molecule with an info attribute
+
+def test_atoms_info_in_traj():
     info = dict(creation_date='2011-06-27',
                 chemical_name='Hydrogen',
                 # custom classes also works provided that it is
@@ -12,18 +12,14 @@ def test_info():
     molecule = Atoms('H2', positions=[(0., 0., 0.), (0., 0., 1.1)], info=info)
     assert molecule.info == info
 
-    # Copy molecule
     atoms = molecule.copy()
     assert atoms.info == info
 
-    # Save molecule to trajectory
-    traj = Trajectory('info.traj', 'w', atoms=molecule)
-    traj.write()
-    del traj
+    with Trajectory('info.traj', 'w', atoms=molecule) as traj:
+        traj.write()
 
-    # Load molecule from trajectory
-    t = Trajectory('info.traj')
-    atoms = t[-1]
+    with Trajectory('info.traj') as traj:
+        atoms = traj[-1]
 
     print(atoms.info)
     assert atoms.info == info
