@@ -1,11 +1,12 @@
-def test_bader():
-    import os
-    from ase.build import molecule
-    from ase.io.bader import attach_charges
+from pathlib import Path
 
+from ase.build import molecule
+from ase.io.bader import attach_charges
+
+
+def test_bader():
     fname = 'ACF.dat'
-    f = open(fname, 'w')
-    print("""
+    Path(fname).write_text("""
        #         X           Y           Z        CHARGE     MIN DIST
      ----------------------------------------------------------------
        1      7.0865      8.5038      9.0672      9.0852      1.3250
@@ -13,8 +14,7 @@ def test_bader():
        3      7.0865      7.0615      7.9403      0.4574      0.3159
      ----------------------------------------------------------------
       NUMBER OF ELECTRONS:        9.99999
-    """, file=f)
-    f.close()
+    """)
 
     atoms = molecule('H2O')
     atoms.set_cell([7.5, 9, 9])
@@ -22,7 +22,6 @@ def test_bader():
 
     attach_charges(atoms)
     attach_charges(atoms, fname)
-    os.remove(fname)
 
     for atom in atoms:
         print('Atom', atom.symbol, 'Bader charge', atom.charge)
