@@ -6,32 +6,32 @@ from ase.dimer import DimerControl, MinModeAtoms, MinModeTranslate
 
 def test_dimer_method():
     # Set up a small "slab" with an adatoms
-    atoms = fcc100('Pt', size = (2, 2, 1), vacuum = 10.0)
+    atoms = fcc100('Pt', size=(2, 2, 1), vacuum=10.0)
     add_adsorbate(atoms, 'Pt', 1.611, 'hollow')
 
     # Freeze the "slab"
     mask = [atom.tag > 0 for atom in atoms]
-    atoms.set_constraint(FixAtoms(mask = mask))
+    atoms.set_constraint(FixAtoms(mask=mask))
 
     # Calculate using EMT
     atoms.calc = EMT()
     atoms.get_potential_energy()
 
     # Set up the dimer
-    d_control = DimerControl(initial_eigenmode_method = 'displacement', \
-                             displacement_method = 'vector', logfile = None, \
-                             mask = [0, 0, 0, 0, 1])
+    d_control = DimerControl(initial_eigenmode_method='displacement',
+                             displacement_method='vector', logfile=None,
+                             mask=[0, 0, 0, 0, 1])
     d_atoms = MinModeAtoms(atoms, d_control)
 
     # Displace the atoms
-    displacement_vector = [[0.0]*3]*5
+    displacement_vector = [[0.0] * 3] * 5
     displacement_vector[-1][1] = -0.1
-    d_atoms.displace(displacement_vector = displacement_vector)
+    d_atoms.displace(displacement_vector=displacement_vector)
 
     # Converge to a saddle point
-    dim_rlx = MinModeTranslate(d_atoms, trajectory = 'dimer_method.traj', \
-                               logfile = None)
-    dim_rlx.run(fmax = 0.001)
+    dim_rlx = MinModeTranslate(d_atoms, trajectory='dimer_method.traj',
+                               logfile=None)
+    dim_rlx.run(fmax=0.001)
 
     # Test the results
     tolerance = 1e-3
