@@ -7,15 +7,15 @@ def test_stm():
     stm = STM(atoms, [0, 1, 2])
     c = stm.get_averaged_current(-1.0, 4.5)
     x, y, h = stm.scan(-1.0, c)
-    stm.write('stm.pckl')
-    x, y, h2 = STM('stm.pckl').scan(-1, c)
+    stm.write('stm.json')
+    x, y, h2 = STM('stm.json').scan(-1, c)
     assert abs(h - h2).max() == 0
 
     stm = STM(atoms, use_density=True)
     c = stm.get_averaged_current(-1, 4.5)
     x, y, I = stm.scan2(-1.0, 1.0)
-    stm.write('stm2.pckl')
-    x, y, I2 = STM('stm2.pckl').scan2(-1, 1)
+    stm.write('stm2.json')
+    x, y, I2 = STM('stm2.json').scan2(-1, 1)
     assert abs(I - I2).max() == 0
 
     stm = STM(atoms, use_density=True)
