@@ -25,9 +25,23 @@ __all__ = ['exec_', 'basestring', 'import_module', 'seterr', 'plural',
 
 # Python 2+3 compatibility stuff (let's try to remove these things):
 basestring = str
-from io import StringIO
 pickleload = functools.partial(pickle.load, encoding='bytes')
-StringIO  # appease pyflakes
+
+
+def deprecated(msg, category=FutureWarning):
+    """Return a decorator deprecating a function.
+
+    Use like @deprecated('warning message and explanation')."""
+    def deprecated_decorator(func):
+        @functools.wraps(func)
+        def deprecated_function(*args, **kwargs):
+            warning = msg
+            if not isinstance(warning, Warning):
+                warning = category(warning)
+            warnings.warn(warning)
+            return func(*args, **kwargs)
+        return deprecated_function
+    return deprecated_decorator
 
 
 @contextmanager
@@ -58,24 +72,35 @@ class DevNull:
     encoding = 'UTF-8'
     closed = False
 
+    _use_os_devnull = deprecated('use open(os.devnull) instead',
+                                 DeprecationWarning)
+    # Deprecated for ase-3.21.0.  Change to futurewarning later on.
+
+    @_use_os_devnull
     def write(self, string):
         pass
 
+    @_use_os_devnull
     def flush(self):
         pass
 
+    @_use_os_devnull
     def seek(self, offset, whence=0):
         return 0
 
+    @_use_os_devnull
     def tell(self):
         return 0
 
+    @_use_os_devnull
     def close(self):
         pass
 
+    @_use_os_devnull
     def isatty(self):
         return False
 
+    @_use_os_devnull
     def read(self, n=-1):
         return ''
 
@@ -92,10 +117,10 @@ def convert_string_to_fd(name, world=None):
     if world is None:
         from ase.parallel import world
     if name is None or world.rank != 0:
-        return devnull
+        return open(os.devnull, 'w')
     if name == '-':
         return sys.stdout
-    if isinstance(name, (basestring, PurePath)):
+    if isinstance(name, (str, PurePath)):
         return open(str(name), 'w')  # str for py3.5 pathlib
     return name  # we assume name is already a file-descriptor
 
@@ -104,7 +129,8 @@ def convert_string_to_fd(name, world=None):
 CEW_FLAGS = os.O_CREAT | os.O_EXCL | os.O_WRONLY | getattr(os, 'O_BINARY', 0)
 
 
-def opencew(filename, world=None):
+@contextmanager
+def xwopen(filename, world=None):
     """Create and open filename exclusively for writing.
 
     If master cpu gets exclusive write access to filename, a file
@@ -112,28 +138,53 @@ def opencew(filename, world=None):
     slaves).  If the master cpu does not get write access, None is
     returned on all processors."""
 
+    fd = opencew(filename, world)
+    try:
+        yield fd
+    finally:
+        if fd is not None:
+            fd.close()
+
+
+#@deprecated('use "with xwopen(...) as fd: ..." to prevent resource leak')
+def opencew(filename, world=None):
+    return _opencew(filename, world)
+
+
+def _opencew(filename, world=None):
     if world is None:
         from ase.parallel import world
 
-    if world.rank == 0:
-        try:
-            fd = os.open(filename, CEW_FLAGS)
-        except OSError as ex:
-            error = ex.errno
-        else:
-            error = 0
-            fd = os.fdopen(fd, 'wb')
-    else:
-        error = 0
-        fd = devnull
+    closelater = []
 
-    # Syncronize:
-    error = world.sum(error)
-    if error == errno.EEXIST:
-        return None
-    if error:
-        raise OSError(error, 'Error', filename)
-    return fd
+    def opener(file, flags):
+        return os.open(file, flags | CEW_FLAGS)
+
+    try:
+        error = 0
+        if world.rank == 0:
+            try:
+                fd = open(filename, 'wb', opener=opener)
+            except OSError as ex:
+                error = ex.errno
+            else:
+                closelater.append(fd)
+        else:
+            fd = open(os.devnull, 'wb')
+            closelater.append(fd)
+
+        # Synchronize:
+        error = world.sum(error)
+        if error == errno.EEXIST:
+            return None
+        if error:
+            raise OSError(error, 'Error', filename)
+
+        return fd
+    except BaseException:
+        for fd in closelater:
+            fd.close()
+        raise
 
 
 class Lock:
@@ -384,35 +435,39 @@ def workdir(path, mkdir=False):
         os.chdir(olddir)
 
 
-def iofunction(func, mode):
+class iofunction:
     """Decorate func so it accepts either str or file.
 
     (Won't work on functions that return a generator.)"""
+    def __init__(self, mode):
+        self.mode = mode
+
+    def __call__(self, func):
+        @functools.wraps(func)
+        def iofunc(file, *args, **kwargs):
+            openandclose = isinstance(file, (str, PurePath))
+            fd = None
+            try:
+                if openandclose:
+                    fd = open(str(file), self.mode)
+                else:
+                    fd = file
+                obj = func(fd, *args, **kwargs)
+                return obj
+            finally:
+                if openandclose and fd is not None:
+                    # fd may be None if open() failed
+                    fd.close()
+        return iofunc
 
-    @functools.wraps(func)
-    def iofunc(file, *args, **kwargs):
-        openandclose = isinstance(file, (basestring, PurePath))
-        fd = None
-        try:
-            if openandclose:
-                fd = open(str(file), mode)
-            else:
-                fd = file
-            obj = func(fd, *args, **kwargs)
-            return obj
-        finally:
-            if openandclose and fd is not None:
-                # fd may be None if open() failed
-                fd.close()
-    return iofunc
 
 
 def writer(func):
-    return iofunction(func, 'w')
+    return iofunction('w')(func)
 
 
 def reader(func):
-    return iofunction(func, 'r')
+    return iofunction('r')(func)
 
 
 # The next two functions are for hotplugging into a JSONable class
@@ -504,6 +559,13 @@ def lazymethod(meth):
     return getter
 
 
+def atoms_to_spglib_cell(atoms):
+    """Convert atoms into data suitable for calling spglib."""
+    return (atoms.get_cell(),
+            atoms.get_scaled_positions(),
+            atoms.get_atomic_numbers())
+
+
 def warn_legacy(feature_name):
     warnings.warn(
         f'The {feature_name} feature is untested and ASE developers do not '
@@ -515,19 +577,3 @@ def warn_legacy(feature_name):
 def lazyproperty(meth):
     """Decorator like lazymethod, but making item available as a property."""
     return property(lazymethod(meth))
-
-
-def deprecated(msg):
-    """Return a decorator deprecating a function.
-
-    Use like @deprecated('warning message and explanation')."""
-    def deprecated_decorator(func):
-        @functools.wraps(func)
-        def deprecated_function(*args, **kwargs):
-            warning = msg
-            if not isinstance(warning, Warning):
-                warning = FutureWarning(warning)
-            warnings.warn(warning)
-            return func(*args, **kwargs)
-        return deprecated_function
-    return deprecated_decorator
