@@ -7,4 +7,4 @@ a.calc = FreeElectrons(nvalence=1,
                        kpts={'path': 'GXWLGK', 'npoints': 200})
 a.get_potential_energy()
 bs = a.calc.band_structure()
-bs.plot(emax=10, filename='cu.png')
+bs.plot(emin=0, emax=20, filename='cu.png')
