@@ -13,7 +13,7 @@ calc = GPAW(h=h, occupations=FermiDirac(width=0.1),
             eigensolver='cg', symmetry={'point_group': False},
             nbands=10, convergence={'eigenstates':1.e-5, 
                                     'bands':4})
-atoms.set_calculator(calc)
+atoms.calc = calc
 
 # use only the 4 converged states for linear response calculation
 rr = ResonantRaman(atoms, LrTDDFT, exkwargs={'jend':3})
