@@ -10,10 +10,13 @@ extensions = ['ext',
               'images',
               'sphinx.ext.autodoc',
               'sphinx.ext.doctest',
+              'sphinx.ext.extlinks',
               'sphinx.ext.mathjax',
               'sphinx.ext.viewcode',
               'sphinx.ext.napoleon',
               'sphinx.ext.intersphinx']
+extlinks = {'doi': ('https://doi.org/%s', 'doi:'),
+            'arxiv': ('https://arxiv.org/abs/%s', 'arXiv:')}
 source_suffix = '.rst'
 master_doc = 'index'
 project = 'ASE'
@@ -41,8 +44,8 @@ html_favicon = 'static/ase.ico'
 html_static_path = ['static']
 html_last_updated_fmt = '%a, %d %b %Y %H:%M:%S'
 
-ase_dev_version = '3.20.2b1'  # This line auto-edited by newrelease script
-ase_stable_version = '3.20.1'  # This line auto-edited by newrelease script
+ase_dev_version = '3.21.2b1'  # This line auto-edited by newrelease script
+ase_stable_version = '3.21.1'  # This line auto-edited by newrelease script
 
 html_context = {
     'current_version': __version__,
