@@ -45,24 +45,26 @@ Nbulk = len(idx)
 multiples = [0, 1, -1]
 for i in multiples:
     for j in multiples:
-            if i == j == 0:
-                continue
-            chunk = atoms[idx]
-            chunk.translate(i * cell[0] + j * cell[1])
-            atoms += chunk
-            transmittances += [0.8] * Nbulk
-            textures += ['pale'] * Nbulk
+        if i == j == 0:
+            continue
+        chunk = atoms[idx]
+        chunk.translate(i * cell[0] + j * cell[1])
+        atoms += chunk
+        transmittances += [0.8] * Nbulk
+        textures += ['pale'] * Nbulk
 
 bbox = [-30, 10, 5, 25]
 
-write('o2pt100.pov', atoms,
-      rotation='90z,-75x',
-      show_unit_cell=0,
-      run_povray=True,
-      pause=False,
-      canvas_width=1024,
-      bondatoms=bonded_atoms,
-      camera_type='perspective',
-      transmittances=transmittances,
-      textures=textures,
-      bbox=bbox)
+renderer = write('o2pt100.pov', atoms,
+                 rotation='90z,-75x',
+                 bbox=bbox,
+                 show_unit_cell=0,
+                 povray_settings=dict(
+                     pause=False,
+                     canvas_width=1024,
+                     bondatoms=bonded_atoms,
+                     camera_type='perspective',
+                     transmittances=transmittances,
+                     textures=textures))
+
+renderer.render()
