@@ -9,11 +9,11 @@ d = 1.10
 
 slab = fcc111('Cu', size=(4, 4, 2), vacuum=10.0)
 
-slab.set_calculator(EMT())
+slab.calc = EMT()
 e_slab = slab.get_potential_energy()
 
 molecule = Atoms('2N', positions=[(0., 0., 0.), (0., 0., d)])
-molecule.set_calculator(EMT())
+molecule.calc = EMT()
 e_N2 = molecule.get_potential_energy()
 
 add_adsorbate(slab, molecule, h, 'ontop')
