@@ -1,6 +1,6 @@
 import json
 from pathlib import Path
-from typing import Tuple, Dict  # noqa
+from typing import Tuple
 from ase.eos import EquationOfState as EOS
 from ase.io import read
 
@@ -12,14 +12,14 @@ def fit(symbol: str) -> Tuple[float, float, float, float]:
         V.append(atoms.get_volume() / len(atoms))
         E.append(atoms.get_potential_energy() / len(atoms))
     eos = EOS(V, E, 'birchmurnaghan')
-    eos.fit()
+    eos.fit(warn=False)
     e0, B, Bp, v0 = eos.eos_parameters
     return e0, v0, B, Bp
 
 
-data = {}  # type: Dict[Dict[str, float]]
+data = {}  # Dict[str, Dict[str, float]]
 for path in Path().glob('*.traj'):
-    symbol = path.name.split('.')[0]
+    symbol = path.stem
     e0, v0, B, Bp = fit(symbol)
     data[symbol] = {'emt_energy': e0,
                     'emt_volume': v0,
