@@ -5,7 +5,7 @@ atoms = molecule('C6H6')
 atoms.center(vacuum=3.5)
 
 calc = GPAW(h=.21, xc='PBE', txt='benzene.txt', nbands=18)
-atoms.set_calculator(calc)
+atoms.calc = calc
 atoms.get_potential_energy()
 
 calc.set(fixdensity=True, txt='benzene-harris.txt',
